aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Function.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2005-01-30 00:09:23 +0000
committerChris Lattner <sabre@nondot.org>2005-01-30 00:09:23 +0000
commitbca81448ac8e19c588c9a4ad16fc70732b76327c (patch)
treeeb4d515aa88a94cc20e36908ff4336a032129399 /include/llvm/Function.h
parent5c3fa1ec79b3e37e364641a995e08e0ddd933372 (diff)
downloadexternal_llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.zip
external_llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.gz
external_llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.bz2
Improve conformance with the Misha spelling benchmark suite
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@19930 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Function.h')
-rw-r--r--include/llvm/Function.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/llvm/Function.h b/include/llvm/Function.h
index 88d7d34..6c1f469 100644
--- a/include/llvm/Function.h
+++ b/include/llvm/Function.h
@@ -31,18 +31,18 @@ class FunctionType;
template<> struct ilist_traits<BasicBlock>
: public SymbolTableListTraits<BasicBlock, Function, Function> {
- // createSentinal is used to create a node that marks the end of the list...
- static BasicBlock *createSentinal();
- static void destroySentinal(BasicBlock *BB) { delete BB; }
+ // createSentinel is used to create a node that marks the end of the list...
+ static BasicBlock *createSentinel();
+ static void destroySentinel(BasicBlock *BB) { delete BB; }
static iplist<BasicBlock> &getList(Function *F);
};
template<> struct ilist_traits<Argument>
: public SymbolTableListTraits<Argument, Function, Function> {
- // createSentinal is used to create a node that marks the end of the list...
- static Argument *createSentinal();
- static void destroySentinal(Argument *A) { delete A; }
+ // createSentinel is used to create a node that marks the end of the list...
+ static Argument *createSentinel();
+ static void destroySentinel(Argument *A) { delete A; }
static iplist<Argument> &getList(Function *F);
};